==> knative-model-6.8.0-sources.jar: io/fabric8/knative/serving/v1beta1/SecretTLSFluent.java <==
package io.fabric8.knative.serving.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SecretTLSFluent<A extends SecretTLSFluent<A>> extends BaseFluent<A>{
  public SecretTLSFluent() {
  }
  public SecretTLSFluent(SecretTLS instance) {
    instance = (instance != null ? instance : new SecretTLS());

    if (instance != null) {
      this.withSecretName(instance.getSecretName());
      this.withSecretName(instance.getSecretName());
    }
  }
  private String secretName;
  public String getSecretName() {
    return this.secretName;
  }
  public A withSecretName(String secretName) {
    this.secretName=secretName; return (A) this;
  }
  public boolean hasSecretName() {
    return this.secretName != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretTLSFluent that = (SecretTLSFluent) o;
    if (!java.util.Objects.equals(secretName, that.secretName)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(secretName,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretName != null) { sb.append("secretName:"); sb.append(secretName); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/serving/v1beta1/SecretTLSFluent.java <==
package io.fabric8.knative.serving.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SecretTLSFluent<A extends SecretTLSFluent<A>> extends BaseFluent<A>{
  public SecretTLSFluent() {
  }
  
  public SecretTLSFluent(SecretTLS instance) {
    this.copyInstance(instance);
  }
  private String secretName;
  
  protected void copyInstance(SecretTLS instance) {
    instance = (instance != null ? instance : new SecretTLS());
  
    if (instance != null) {
        this.withSecretName(instance.getSecretName());
        this.withSecretName(instance.getSecretName());
      }
  }
  
  public String getSecretName() {
    return this.secretName;
  }
  
  public A withSecretName(String secretName) {
    this.secretName=secretName; return (A) this;
  }
  
  public boolean hasSecretName() {
    return this.secretName != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretTLSFluent that = (SecretTLSFluent) o;
    if (!java.util.Objects.equals(secretName, that.secretName)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(secretName,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretName != null) { sb.append("secretName:"); sb.append(secretName); }
    sb.append("}");
    return sb.toString();
  }
  

}
